<?php
/**
 * Medic52 WPStatus Admin
 *
 * @class    MWPS_Admin
 */

defined( 'ABSPATH' ) || exit;

/**
 * MWPS_Admin class.
 */
class MWPS_Admin {

    /**
     * Constructor.
     */
    public function __construct() {
        // Add menus.
        add_action( 'admin_menu', array( $this, 'admin_menu' ), 9 );

        // Enqueue styles / scripts
        add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );

        // footer js
        //add_action( 'admin_footer', array( $this, 'admin_footer' ) );

        // admin ajax
        add_action('wp_ajax_mwps_validate_data_feed_url', array($this, 'mwps_validate_data_feed_url'));
    }

    /**
     * Add menu items.
     */
    public function admin_menu() {
        add_options_page( __(MWPS_PLUGIN_NAME, MWPS_TEXT_DOMAIN), __(MWPS_PLUGIN_NAME, MWPS_TEXT_DOMAIN), 'manage_options', MWPS_TEXT_DOMAIN, array( $this, 'settings_page' ));
    }

    public function admin_scripts() {
        $screen = get_current_screen();
        wp_register_style( 'mlts_admin_styles', MWPS()->plugin_url() . '/assets/css/admin.css', array(), MWPS_VERSION );
        wp_register_script( 'mlts_admin_script', MWPS()->plugin_url() . '/assets/js/admin.js', array('jquery'), MWPS_VERSION, true );

        if( isset( $screen->base ) && $screen->base == 'settings_page_'.MWPS_TEXT_DOMAIN ) {
            wp_enqueue_style( 'mlts_admin_styles' );

            wp_enqueue_style( 'wp-color-picker' );
	        wp_enqueue_script( 'wp-color-picker');
            if ( ! did_action( 'wp_enqueue_media' ) ) {
                wp_enqueue_media();
            }
            wp_enqueue_script( 'mlts_admin_script' );
        }
        wp_localize_script( 'mlts_admin_script', 'mlts_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    }

    /**
     * Init the settings page.
     */
    public function settings_page() {

        $optionsName = MWPS_TEXT_DOMAIN.'_options';

        if( isset( $_POST[$optionsName] ) ){
            $submittedData = (array) $_POST[$optionsName];
            $submittedData = mlts_array_map_recursive( 'esc_attr', $submittedData );
            //echo '<pre>';print_r($submittedData);echo '</pre>';
            $submittedData['list_lifts_separately'] = (isset($submittedData['list_lifts_separately'])) ? $submittedData['list_lifts_separately'] : 0;
            $options = get_option($optionsName);
            $newOptions = array_merge($options, $submittedData);
            update_option( $optionsName, $newOptions );
        }
        $options = get_option($optionsName);
        $dataFeedUrl = isset($options['data_feed_url']) ? $options['data_feed_url'] : '';
        $customIcons = isset($options['custom_icons']) ? $options['custom_icons'] : '';
        ?>
        <div class="wrap" id="mLTStatusWrap">
            <h2><?php echo MWPS_PLUGIN_NAME . __(' Settings', MWPS_TEXT_DOMAIN); ?></h2>

            <div class="row">
                <div class="col-8">
            <form method="post" action="">
                <?php settings_fields(MWPS_TEXT_DOMAIN.'_options'); ?>

                <div class="dataFeedURLWrap">
                    <?php
                    $validate = isset($options['validate']) ? $options['validate'] : [];
                    $valid = (isset($validate['valid']) && $validate['valid'] == 1) ? 1 : 0;
                    $validUrl = isset($validate['url']) ? $validate['url'] : '';
                    $validCls = '';
                    $msg = '';
                    $inputDisabled = '';
                    if($valid && $validUrl == $dataFeedUrl) {
                        $validCls .= 'success';
                        $msg = 'Validated successful!';
                        $inputDisabled = 'disabled="true"';
                    } elseif(!$valid || $validUrl !== $dataFeedUrl) {
                        $validCls .= 'failed';
                        $msg = 'Validated failed!';
                    }
                    ?>
                    <h3>Datafeed URL</h3>
                    <p class="dataFeedURL <?php echo $validCls;?>"><input type="text" name="<?php echo esc_html($optionsName);?>[data_feed_url]" id="data_feed_url" value="<?php echo esc_url($dataFeedUrl);?>" class="" <?php echo $inputDisabled;?>></p>
                    <p class="help">Enter your MTN.XML URL (JSON or XML format) in order to activate the plugin. If you are a Medic52 client, you can find this in your Medic52 system at Settings > Resort Settings

                    </p>
                    <?php
                    if($valid && $validUrl == $dataFeedUrl) {
                    ?>
                        <button class="validate-btn button changeURL">Change URL</button>
                    <?php } else { ?>
                        <button class="validate-btn button validateURL">Validate</button>
                    <?php } ?>
                </div>

                <div class="mLTSTabsWrap <?php echo $validCls;?>">
                    <nav class="nav-tab-wrapper mlts-nav-tab-wrapper">
                        <a class="nav-tab nav-tab-active" href="#tab-installation">Installation</a>
                        <a class="nav-tab" href="#tab-customisation">Customisation</a>
                    </nav>
                    <div class="tabsContent">
                    <div id="tab-installation" class="tab-content">
                        <h3>Installation</h3>
                        <p>It's easy to install this on your website. Create a new page and place the shortcode below on to the page. The plugin will do the rest and render your Lifts and Trails according to your preferences.</p>
                        <div class="mLTSShortcodeWrap">
                            <p style="font-size: 1.5rem;">[medic52_lift_trail_status]</p>
                            <p><a class="btn button" target="_blank" href="<?php echo admin_url('post-new.php?post_type=page');?>">Create a new page</a></p>
                        </div>
                    </div>
                    <div id="tab-customisation" class="tab-content">
                        <h3>Ratings Customisation</h3>
                        <p>There are 5 possible run ratings that are used in the system. Use this section to customise the Label, color and icon to represent the run difficulties you use. If you wish you can upload your own icon. We recommend 24x24px.</p>

                        <table class="form-table">
                            <tr>
                                <th></th>
                                <th><?php echo __('Label', MWPS_TEXT_DOMAIN);?></th>
                                <th><?php echo __('Color', MWPS_TEXT_DOMAIN);?></th>
                                <th><?php echo __('Icon', MWPS_TEXT_DOMAIN);?></th>
                            </tr>
                            <?php foreach (MLTS_RATINGS_OPTION as $key=>$rating) {
                                $name = ucwords(str_replace('_', ' ', trim($key)));
                                $ratingsOptions = isset($options['ratings']) ? $options['ratings'] : [];
                                $keyOptions = isset($ratingsOptions[$key]) ? $ratingsOptions[$key] : [];
                                $label = (isset($keyOptions['label'])) ? $keyOptions['label'] : $rating['label'];
                                $color = (isset($keyOptions['color'])) ? $keyOptions['color'] : $rating['color'];
                                $icon = (isset($keyOptions['icon'])) ? $keyOptions['icon'] : '';
                                ?>
                            <tr>
                                <th scope="row"><?php echo __($name, MWPS_TEXT_DOMAIN);?></th>
                                <td><input type="text" name="<?php echo $optionsName;?>[ratings][<?php echo $key; ?>][label]" id="<?php echo $key; ?>_label" value="<?php echo esc_html($label);?>"></td>
                                <td><input type="text" name="<?php echo $optionsName;?>[ratings][<?php echo $key; ?>][color]" id="<?php echo $key; ?>_color" value="<?php echo esc_html($color);?>" class="colorPicker"></td>
                                <td class="iconColWrap">
                                    <?php
                                    echo mlts_image_uploader_field( $key, $optionsName."[ratings][".$key."][icon]", $icon );
                                    ?>
                                </td>
                            </tr>
                            <?php } ?>
                        </table>

                        <h3>Layout Customisation</h3>
                        <?php
                        $listLiftsSeparately = isset($options['list_lifts_separately']) ? $options['list_lifts_separately'] : 0;
                        if($listLiftsSeparately) $lLSChecked = 'checked="checked"';
                        else $lLSChecked = '';
                        ?>
                        <table class="form-table">
                            <tbody>
                            <tr>
                                <th>List Lifts separately</th>
                                <td>
                                    <fieldset>
                                        <label for="list_lifts_separately">
                                            <input type="checkbox" name="<?php echo esc_html($optionsName);?>[list_lifts_separately]" id="list_lifts_separately" value="1" <?php echo $lLSChecked;?> >
                                        </label>
                                    </fieldset>
                                </td>
                            </tr>
                            </tbody>
                        </table>


                        <?php submit_button('Save'); ?>
                    </div>
                    </div>
                </div>

            </form>
                </div>
                <div class="col-4 sidebarCol">
                    <div class="sidebarInner">
                        <p>This plugin is brought to you by Medic52.</p>
                        <p>Medic52 is a risk management data platform for the leisure and outdoor industry that removes the pain of managing the associated paperwork.</p>
                        <p>Medic52 has a one of a kind map based dispatch, configurable incident collection forms, training passport, asset management and incident investigation library.</p>
                        <p>Trail & Lift status is part of the asset management system and enables a ski resort to keep their website up to date with what is happening on the hill through a live data feed.</p>
                        <p><a href="https://www.medic52.com/">Website</a></p>
                        <p><a href="https://www.medic52.com/">Documentation</a></p>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    public function mwps_validate_data_feed_url() {
        $url = trim(esc_url_raw($_POST['url']));

        // find '/json/' at the end of URL, append if not found
        /*$subURL = substr($url, -5);
        if(strpos($subURL, 'json') === FALSE) {
            $url .= '/json/';
        }*/

        $response = ['url'=>$url];
        // get the existing option value
        $optionsName = MWPS_TEXT_DOMAIN.'_options';
        $options = get_option($optionsName);

        $options['data_feed_url'] = $url;
        $obj = mwps_get_data($url);
        $feed_type = (isset($obj['feed_type'])) ? $obj['feed_type'] : '';
        $areas = mlts_get_areas($obj);
        //if(isset($obj['facilities']) && isset($obj['facilities']['areas'])) {
        if(count($areas) > 0) {
            // update the existing option value
            $options['validate'] = ['valid' => 1, 'url' => $url];
            $response['success'] = true;
        } else {
            $options['validate'] = ['valid' => 0, 'url' => $url];
            $response['success'] = false;
        }
        $options['validate']['feed_type'] = $feed_type;
        //$response['facilities'] = $obj;
        // update
        update_option($optionsName, $options);
        echo json_encode($response);
        die();
    }

    // Admin footer js
    public function admin_footer() {
        $screen = get_current_screen();
        //print_r($screen);
        if( isset( $screen->base ) && $screen->base == 'settings_page_'.MWPS_TEXT_DOMAIN ) {
            $js = "<script>
                
            </script>";

            echo apply_filters( 'mlts_queued_js', $js );
        }
    }
}

return new MWPS_Admin();
