<?php
/**
 * Installation related functions and actions.
 *
 */

defined( 'ABSPATH' ) || exit;

/**
 * MWPS_Install Class.
 */
class MWPS_Install {
    /**
     * Hook in tabs.
     */
    public static function init() {
        add_filter( 'plugin_action_links_' . MWPS_PLUGIN_BASENAME, array( __CLASS__, 'plugin_action_links' ) );

        add_action( 'admin_notices', array( __CLASS__, 'admin_notices' ) );
    }

    /**
     * Install MWPS.
     */
    public static function install() {

        if ( ! is_blog_installed() ) {
            return;
        }

        // Check if we are not already running this routine.
        if ( 'yes' === get_transient( 'mwps_installing' ) ) {
            return;
        }

        // If we made it till here nothing is running yet, lets set the transient now.
        set_transient( 'mwps_installing', 'yes', HOUR_IN_SECONDS * 10 );
    }

    /**
     * Show action links on the plugin screen.
     *
     * @param mixed $links Plugin Action links.
     *
     * @return array
     */
    public static function plugin_action_links( $links ) {
        $action_links = array(
            'settings' => '<a href="' . admin_url( 'options-general.php?page='.MWPS_TEXT_DOMAIN ) . '" aria-label="' . esc_attr__( 'View settings page', MWPS_TEXT_DOMAIN ) . '">' . esc_html__( 'Settings', MWPS_TEXT_DOMAIN ) . '</a>',
        );

        return array_merge( $action_links, $links );
    }

    /**
     * Output a admin notice.
     *
     * @return void
     */
    public static function admin_notices() {
        /* Check transient, if available display notice */
        if( get_transient( 'mwps_installing' ) ){
            ?>
            <div class="updated notice is-dismissible">
                <p><strong>Data Feed URL Needed</strong> Enter your URL in order to activate the plugin. Find this in your Medic52 system at Settings > Resort Settings. <strong><a href="<?php echo admin_url( 'options-general.php?page='.MWPS_TEXT_DOMAIN ); ?>">Enter Now</a></strong></p>
            </div>
            <?php
        }
    }
}

MWPS_Install::init();
