<?php
/**
 * Lift Trail Shortcodes
 *
 * Shows the 'lift trail' section.
 */

defined( 'ABSPATH' ) || exit;

/**
 * Shortcode Lift Trail class.
 */
class MLTS_Shortcode_Lift_Trail {

    /**
     * Get the shortcode content.
     *
     * @param array $atts Shortcode attributes.
     *
     * @return string
     */
    public static function get( $atts ) {
        return MLTS_Shortcodes::shortcode_wrapper( array( __CLASS__, 'output' ), $atts );
    }

    /**
     * Output the shortcode.
     *
     * @param array $atts Shortcode attributes.
     */
    public static function output( $atts ) {
        // Start output buffer since the html may need discarding for BW compatibility.
        ob_start();

        // Output the lift trail page.
        self::lift_trail( $atts );

        // Send output buffer.
        ob_end_flush();
    }

    /**
     * Lift trail page.
     *
     * @param array $atts Shortcode attributes.
     */
    private static function lift_trail( $atts ) {
        $args = shortcode_atts(
            array(
            ),
            $atts,
            'medic52_lift_trail_status'
        );

        $optionsName = MWPS_TEXT_DOMAIN.'_options';
        $options = get_option($optionsName);
        $ratingsOptions = isset($options['ratings']) ? $options['ratings'] : MLTS_RATINGS_OPTION;
        $listLiftsSeparately = isset($options['list_lifts_separately']) ? $options['list_lifts_separately'] : 0;
        $image_size = 'full';
        $url = esc_url_raw($options['data_feed_url']);

        $obj = mwps_get_data($url);
        $feed_type = (isset($obj['feed_type'])) ? $obj['feed_type'] : '';
        do_action('mwps_before_main_wrap', $obj);

        $areas = mlts_get_areas($obj);

        echo '<div class="medic52WPStatusWrap">';
        if(count($areas) > 0) {
            //$facilities = $obj['facilities'];
            //$areas = $facilities['areas'];

            /*echo '<pre>';
            print_r($areas);
            echo '</pre>';*/
            ?>
            <div class="mWPSWrap">
                <?php if($listLiftsSeparately) {?>
                <div class="mWPSAreasWrap mWPSLiftsWrap">
                    <?php
                    echo apply_filters('mwps_lifts_status_header', '<h2>'.__('Lifts Status', MWPS_TEXT_DOMAIN).'</h2>');
                    echo '<hr class="mWPSBorder">';
                    ?>
                    <div class="mWPSFilterWrap mWPSLiftFilterWrap">
                        <!--<h3><?php /*echo apply_filters('mwps_lifts_filter_legend', __('Lifts Status Legend', MWPS_TEXT_DOMAIN));*/?></h3>-->
                        <div class="mWPSFilter mWPSLiftFilter">
                            <div class="mWPSFilterList mWPSLiftFilterList">
                                <div class="mWPSFilterListStatus mWPSLiftFilterListStatus">
                                    <div class="mWPSFilterListBox mWPSLiftFilterListStatusBox">
                                        <span class="statusIcon icon-status-closed"></span><span class="statusIconValue"><?php echo __('Closed', MWPS_TEXT_DOMAIN);?></span>
                                    </div>
                                    <div class="mWPSFilterListBox mWPSLiftFilterListStatusBox">
                                        <span class="statusIcon icon-status-open"></span><span class="statusIconValue"><?php echo __('Open', MWPS_TEXT_DOMAIN);?></span>
                                    </div>
                                    <div class="mWPSFilterListBox mWPSLiftFilterListStatusBox">
                                        <span class="statusIcon icon-status-hold"></span><span class="statusIconValue"><?php echo __('On-Hold', MWPS_TEXT_DOMAIN);?></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                    // just show 1 area if lifts are in 1 area
                    $liftsAreas = self::lift_areas($areas, $feed_type);
                    $areasNo = $liftsAreas['areasNo'];
                    if($areasNo < 2) {
                        $key = $liftsAreas['liftsKey'];
                        // reset areas
                        $_areas[] = $areas[$key];
                    } else $_areas = $areas;
                    $areaKey = 0;
                    foreach ($_areas as $area) {//echo '<pre>';print_r($area);echo '</pre>';
                        if(!$areaKey) {
                            $panelOpen = 'panelOpen';
                            $listDisplay = 'block';
                        }
                        else {
                            $panelOpen = '';
                            $listDisplay = 'none';
                        }
                        $areaKey++;
                        ?>
                        <div class="mWPSAreaWrap <?php echo $panelOpen; ?>">
                            <div class="mWPSAreaHeader">
                                <div class="mWPSAreaIcon">
                                    <!--<span class="icon-lift-gondola"></span>-->
                                    <span class="lift-area-icon">
                                        <img src="<?php echo MWPS_PLUGIN_URL?>assets/img/icon_triplechair.png" alt="icon_triplechair">
                                    </span>
                                    <span class="togglePanelCtrl pull-right">
                                        <span class="togglePanelCtrl--doClose icon-misc-accordion-minus"></span>
                                        <span class="togglePanelCtrl--doOpen icon-misc-accordion-plus"></span>
                                    </span>
                                </div>
                                <div class="mWPSAreaInfo">
                                    <h2>
                                        <?php echo isset($area['name']) ? esc_html($area['name']) : '';?>
                                        <span class="togglePanelCtrl pull-right">
                                        <span class="togglePanelCtrl--doClose icon-misc-accordion-minus"></span>
                                        <span class="togglePanelCtrl--doOpen icon-misc-accordion-plus"></span>
                                    </span>
                                    </h2>
                                </div>
                            </div>
                            <?php
                            //$lifts = isset($area['lifts']) ? $area['lifts'] : [];
                            $lifts = mlts_get_lifts_trails($area, 'lifts', $feed_type);
                            echo self::liftsList($lifts, $listLiftsSeparately, $listDisplay);
                            ?>
                        </div>
                        <?php
                    }
                    ?>
                </div>
                <?php } ?>
                <div class="mWPSAreasWrap mWPSTrailsWrap">
                    <?php
                    if($listLiftsSeparately) $trailStatusHeader = '<h2>'.__('Trails Status', MWPS_TEXT_DOMAIN).'</h2>';
                    else $trailStatusHeader = '<h2>'.__('Lifts & Trails Status', MWPS_TEXT_DOMAIN).'</h2>';
                    echo apply_filters('mwps_trails_status_header', $trailStatusHeader);
                    echo '<hr class="mWPSBorder">';
                    ?>
                    <div class="mWPSFilterWrap mWPSTrailsFilterWrap">
                        <!--<h3><?php /*echo apply_filters('mwps_trails_filter_legend', __('Trails Status Legend', MWPS_TEXT_DOMAIN));*/?></h3>-->
                        <div class="mWPSFilter mWPSTrailFilter">
                            <div class="mWPSFilterList mWPSTrailFilterList">
                                <div class="mWPSFilterListRating mWPSFilterListTrailRating">
                                    <?php
                                    if(count($ratingsOptions) > 0) {
                                        echo '<div class="filterLabel"><h4>'.__('Difficulty','MWPS_TEXT_DOMAIN').'</h4></div>';
                                        /*$ratingsOptionsSum = count($ratingsOptions);
                                        //dividing array in to two array
                                        $ratingsOptionsCol1 = array_slice($ratingsOptions, 0, $ratingsOptionsSum / 2 + 0.5);
                                        $ratingsOptionsCol2 = array_slice($ratingsOptions, $ratingsOptionsSum / 2 + 0.5, $ratingsOptionsSum);
                                        $newRatingsOptions = [$ratingsOptionsCol1, $ratingsOptionsCol2];
                                        foreach ($newRatingsOptions as $ratingsCol) {*/
                                            echo '<div class="mWPSFilterListBlock">';
                                            //foreach ($ratingsCol as $ratingKey=>$ratingCol) {
                                            foreach ($ratingsOptions as $ratingKey=>$ratingCol) {
                                                $name = (isset($ratingsOptions[$ratingKey]) && isset($ratingsOptions[$ratingKey]['label'])) ? $ratingsOptions[$ratingKey]['label'] : '';
                                                if(empty($name)) $name = ucwords(str_replace('_', ' ', trim($ratingKey)));
                                                $icon = (isset($ratingsOptions[$ratingKey]) && isset($ratingsOptions[$ratingKey]['icon'])) ? $ratingsOptions[$ratingKey]['icon'] : '';
                                                $uploaded = $img = '';
                                                if( $image_attributes = wp_get_attachment_image_src( $icon, $image_size ) ) {
                                                    $uploaded = 'uploaded';
                                                    $img = '<img src="' . esc_url($image_attributes[0]) . '" style="max-width:95%;display:block;" />';
                                                }
                                                ?>
                                                <div class="mWPSFilterListBox mWPSFilterListTrailRatingBox">
                                                    <span class="statusIcon icon-rating-<?php echo esc_html($ratingKey); echo ' '.esc_html($uploaded);?>"><?php echo $img?></span>
                                                    <span class="statusIconValue"><?php echo esc_html($name);?></span>
                                                </div>
                                                <?php
                                            }
                                            echo '</div><!--.mWPSFilterListBlock-->';
                                        //}
                                    }
                                    ?>
                                </div>
                                <div class="mWPSFilterListStatus mWPSTrailFilterListStatus">
                                    <?php echo '<div class="filterLabel filterStatusLabel"><h4>'.__('Status','MWPS_TEXT_DOMAIN').'</h4></div>';?>
                                    <div class="mWPSFilterListBlock">
                                    <div class="mWPSFilterListBox mWPSTrailFilterListStatusBox">
                                        <span class="statusIcon icon-status-closed"></span><span class="statusIconValue"><?php echo __('Closed', MWPS_TEXT_DOMAIN);?></span>
                                    </div>
                                    <div class="mWPSFilterListBox mWPSTrailFilterListStatusBox">
                                        <span class="statusIcon icon-status-open"></span><span class="statusIconValue"><?php echo __('Open', MWPS_TEXT_DOMAIN);?></span>
                                    </div>
                                        <?php if(!$listLiftsSeparately) { ?>
                                        <div class="mWPSFilterListBox mWPSLiftFilterListStatusBox">
                                            <span class="statusIcon icon-status-hold"></span><span class="statusIconValue"><?php echo __('On-Hold', MWPS_TEXT_DOMAIN);?></span>
                                        </div>
                                        <?php } ?>
                                    </div>
                                    <div class="mWPSFilterListBlock">
                                        <div class="mWPSFilterListBox mWPSTrailFilterListStatusBox">
                                            <span class="statusIcon icon-groomed"></span><span class="statusIconValue"><?php echo __('Groomed', MWPS_TEXT_DOMAIN);?></span>
                                        </div>
                                        <div class="mWPSFilterListBox mWPSTrailFilterListStatusBox">
                                            <span class="statusIcon icon-snowflake"></span><span class="statusIconValue"><?php echo __('Snowmaking', MWPS_TEXT_DOMAIN);?></span>
                                        </div>
                                        <div class="mWPSFilterListBox mWPSTrailFilterListStatusBox">
                                            <span class="statusIcon icon-night-operation"></span><span class="statusIconValue"><?php echo __('Night operation', MWPS_TEXT_DOMAIN);?></span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!--<div class="mWPSFilterButton mWPSTrailFilterButton">
                                <button class="mWPSBtn mWPSBtnTrail">
                                    <?php /*echo apply_filters('mwps_filter_button', __('Update', MWPS_TEXT_DOMAIN));*/?>
                                </button>
                            </div>-->
                        </div>
                    </div>
                    <?php
                    $areaKey = 0;
                    foreach ($areas as $area) {
                        if(!$areaKey) {
                            $panelOpen = 'panelOpen';
                            $listDisplay = 'block';
                        }
                        else {
                            $panelOpen = '';
                            $listDisplay = 'none';
                        }
                        $areaKey++;
                        ?>
                        <div class="mWPSAreaWrap <?php echo $panelOpen;?>">
                            <div class="mWPSAreaHeader">
                                <div class="mWPSAreaIcon">
                                    <!--<span class="icon-status-trail-area"></span>-->
                                    <span class="trail-area-icon"><img src="<?php echo MWPS_PLUGIN_URL?>assets/img/icon_map.png" alt="icon map"></span>
                                    <span class="togglePanelCtrl pull-right">
                                        <span class="togglePanelCtrl--doClose icon-misc-accordion-minus"></span>
                                        <span class="togglePanelCtrl--doOpen icon-misc-accordion-plus"></span>
                                    </span>
                                </div>
                                <div class="mWPSAreaInfo">
                                    <h2>
                                        <?php echo isset($area['name']) ? esc_html($area['name']) : '';?>
                                        <span class="togglePanelCtrl pull-right">
                                            <span class="togglePanelCtrl--doClose icon-misc-accordion-minus"></span>
                                            <span class="togglePanelCtrl--doOpen icon-misc-accordion-plus"></span>
                                        </span>
                                    </h2>
                                </div>
                            </div>
                            <?php
                            if(!$listLiftsSeparately) {
                                $lifts = mlts_get_lifts_trails($area, 'lifts', $feed_type);
                                echo self::liftsList($lifts, $listLiftsSeparately, $listDisplay);
                            }
                            //$trails = isset($area['trails']) ? $area['trails'] : [];
                            $trails = mlts_get_lifts_trails($area, 'trails', $feed_type);
                            if(count($trails) > 0) {
                                $trailsSum = count($trails);
                                //dividing array in to two array
                                $trailsCol1 = array_slice($trails, 0, $trailsSum/2 + 0.5);
                                $trailsCol2 = array_slice($trails, $trailsSum/2 + 0.5, $trailsSum);
                                $newTrails = [$trailsCol1, $trailsCol2];
                                ?>
                                <div class="row mWPSList trailsList" style="display: <?php echo $listDisplay;?>">
                                    <?php
                                    if(!$listLiftsSeparately) {
                                        echo '<div class="col-12"><h3 class="headerLabel">';
                                        echo '<img src="'.MWPS_PLUGIN_URL.'assets/img/icon_map.png" alt="trails icon">';
                                        echo __('Trails', MWPS_TEXT_DOMAIN).'</h3></div>';
                                    }
                                    foreach ($newTrails as $trailsCol) {
                                        if(count($trailsCol) < 1) continue;
                                        ?>
                                        <div class="col-6">
                                            <div class="mWPSColHeader trailsColHeader">
                                                <?php echo __('Trails', MWPS_TEXT_DOMAIN); ?>
                                                <!--<span class="pull-right"><?php /*echo __('Groomed', MWPS_TEXT_DOMAIN); */?></span>-->
                                            </div>
                                            <div class="mWPSCol trailsCol">
                                                <?php
                                                foreach ($trailsCol as $trailCol) {
                                                    $trailStatus = (isset($trailCol['status']) && $trailCol['status'] == 'open') ? 'open' : 'closed';
                                                    $trailDifficulty = isset($trailCol['difficulty']) ? $trailCol['difficulty'] : '';
                                                    $icon = (isset($ratingsOptions[$trailDifficulty]) && isset($ratingsOptions[$trailDifficulty]['icon'])) ? $ratingsOptions[$trailDifficulty]['icon'] : '';
                                                    $uploaded = $img = '';
                                                    if( $image_attributes = wp_get_attachment_image_src( $icon, $image_size ) ) {
                                                        $uploaded = 'uploaded';
                                                        $img = '<img src="' . esc_html($image_attributes[0]) . '" style="display:block;" />';
                                                    }
                                                    $trailGroomed = ($trailCol['groomed'] == 'yes') ? 'yes' : 'no';
                                                    $groomedCls = 'groomed-'.$trailStatus.'-'.$trailGroomed;
                                                    $snowMaking = (isset($trailCol['snowMaking']) && $trailCol['snowMaking'] == 'yes') ? 'yes' : 'no';
                                                    $snowMakingCls = 'snowMaking-'.$trailStatus.'-'.$snowMaking;
                                                    $nightOperation = (isset($trailCol['nightOperation']) && $trailCol['nightOperation'] == 'yes') ? 'yes' : 'no';
                                                    $nightOperationCls = 'nightOperation-'.$trailStatus.'-'.$snowMaking;
                                                    ?>
                                                    <div class="mWPSItem trailItem">
                                                        <div class="mWPSItemIcon trailItemIcon statusRatingIcon icon-rating-<?php echo esc_html($trailDifficulty); echo ' '.esc_html($uploaded);?>">
                                                            <?php echo $img;?>
                                                        </div>
                                                        <div class="mWPSItemName trailItemName">
                                                            <?php echo isset($trailCol['name']) ? esc_html($trailCol['name']) : ''; ?>
                                                        </div>
                                                        <div class="trailItemNightOperation <?php echo ($nightOperation == 'yes') ? 'icon-night-operation' : ''; echo ' '.$nightOperationCls; ?>"></div>
                                                        <div class="trailItemSnowMaking <?php echo ($snowMaking == 'yes') ? 'icon-snowflake' : ''; echo ' '.$snowMakingCls; ?>"></div>
                                                        <div class="trailItemGroomed <?php echo ($trailGroomed == 'yes') ? 'icon-groomed' : ''; echo ' '.$groomedCls; ?>"></div>
                                                        <div class="mWPSItemIcon trailItemIcon icon-status-<?php echo esc_html($trailStatus); ?>"></div>
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                            </div>
                                        </div>
                                    <?php } ?>
                                </div>
                                <?php
                            }
                            ?>
                        </div>
                        <?php
                    }
                    ?>
                </div>
            </div>
            <?php
        } else echo __('Nothing found!', MWPS_TEXT_DOMAIN);
        echo '</div>';
        do_action('mwps_after_main_wrap', $obj);
    }

    // count lifts areas
    public static function lift_areas($areas, $feed_type='json') {
        $key = 0;
        $areasNo = 0;
        foreach ($areas as $k=>$area) {
            /*if($feed_type === 'xml') {
                $lifts = ( isset($area['lifts']) && isset($area['lifts'][0]) && isset($area['lifts'][0]['lift']) ) ? $area['lifts'][0]['lift'] : [];
            } else $lifts = isset($area['lifts']) ? $area['lifts'] : [];*/
            $lifts = mlts_get_lifts_trails($area, 'lifts', $feed_type);
            if(count($lifts) > 0) {
                $key = $k;
                $areasNo++;
            }
        }
        return ['liftsKey' => $key, 'areasNo' => $areasNo];
    }
    public static function liftsList($lifts, $listLiftsSeparately, $listDisplay='none') {
        $html = '';
        if(count($lifts) > 0) {
            $liftsSum = count($lifts);
            //dividing array in to two array
            $liftsCol1 = array_slice($lifts, 0, $liftsSum/2 + 0.5);
            $liftsCol2 = array_slice($lifts, $liftsSum/2 + 0.5, $liftsSum);
            $newLifts = [$liftsCol1, $liftsCol2];
            ob_start();
            ?>
            <div class="row mWPSList liftsList" style="display: <?php echo $listDisplay;?>;">
                <?php
                if(!$listLiftsSeparately) {
                    echo '<div class="col-12"><h3 class="headerLabel">';
                    echo '<img src="'.MWPS_PLUGIN_URL.'assets/img/icon_triplechair.png" alt="lifts icon">';
                    echo __('Lifts', MWPS_TEXT_DOMAIN).'</h3></div>';
                }
                foreach ($newLifts as $liftsCol) {
                    if(count($liftsCol) < 1) continue;
                    ?>
                    <div class="col-6">
                        <div class="mWPSColHeader liftsColHeader">
                            <?php echo __('Lifts', MWPS_TEXT_DOMAIN); ?>
                        </div>
                        <div class="mWPSCol liftsCol">
                            <?php
                            foreach ($liftsCol as $col) {
                                $status = (isset($col['status']) && $col['status'] == 'open') ? 'open' : 'closed';
                                $type = isset($col['type']) ? $col['type'] : '';
                                $typeCls = str_replace(' ', '-', trim(strtolower($type)));
                                $persons = isset($col['persons']) ? $col['persons'] : '';
                                $name = isset($col['name']) ? $col['name'] : '';
                                ?>
                                <div class="mWPSItem liftItem">
                                    <div class="mWPSItemIcon trailItemIcon icon-lift-<?php echo esc_html($persons); ?> icon-lift-<?php echo esc_html($typeCls) ?>"></div>
                                    <div
                                    <div class="mWPSItemName liftItemName">
                                        <?php echo esc_html($name); ?>
                                    </div>
                                    <div class="mWPSItemIcon liftItemIcon icon-status-<?php echo esc_html($status); ?>"></div>
                                </div>
                                <?php
                            }
                            ?>
                        </div>
                    </div>
                <?php } ?>
            </div>
            <?php
            $html = ob_get_contents();
            ob_end_clean();
        }
        return $html;
    }
}
